@@ -83,9 +83,13 @@ is_rosetta2 <- function() {
   rosetta2
 }
 
+arch_is_aarch64 <- function() {
+  isTRUE(R.version$arch == "aarch64")
+}
+
 # Returns the type of make command to use to compile depending on the OS
 make_cmd <- function() {
-  if (os_is_windows() && !os_is_wsl()) {
+  if (os_is_windows() && !os_is_wsl() && (Sys.getenv("CMDSTANR_USE_RTOOLS") == "")) {
     "mingw32-make.exe"
   } else {
     "make"
@@ -103,6 +107,14 @@ stanc_cmd <- function() {
 
 # paths and extensions ----------------------------------------------------
 
+short_path <- function(path) {
+  if (os_is_windows()) {
+    utils::shortPathName(path)
+  } else {
+    path
+  }
+}
+
 # Replace `\\` with `/` in a vector of paths
 # Needed for windows if CmdStan version is < 2.21:
 # https://github.com/stan-dev/cmdstanr/issues/1#issuecomment-539118598
@@ -426,6 +438,19 @@ maybe_convert_draws_format <- function(draws, format, ...) {
   )
 }
 
+create_draws_format <- function(format, ...) {
+  format <- sub("^draws_", "", format)
+  switch(
+    format,
+    "array" = posterior::draws_array(...),
+    "df" = posterior::draws_df(...),
+    "data.frame" = posterior::draws_df(...),
+    "list" = posterior::draws_list(...),
+    "matrix" = posterior::draws_matrix(...),
+    "rvars" = posterior::draws_rvars(...),
+    stop("Invalid draws format.", call. = FALSE)
+  )
+}
 
 # convert draws for external packages ------------------------------------------
 
@@ -675,11 +700,14 @@ assert_file_exists <- checkmate::makeAssertionFunction(check_file_exists)
 # Model methods & expose_functions helpers ------------------------------------------------------
 get_cmdstan_flags <- function(flag_name) {
   cmdstan_path <- cmdstanr::cmdstan_path()
-  flags <- wsl_compatible_run(
-    command = "make",
-    args = c("-s", paste0("print-", flag_name)),
-    wd = cmdstan_path
-  )$stdout
+  withr::with_envvar(
+    c("HOME" = short_path(Sys.getenv("HOME"))),
+    flags <- wsl_compatible_run(
+      command = "make",
+      args = c("-s", paste0("print-", flag_name)),
+      wd = cmdstan_path
+    )$stdout
+  )
 
   flags <- gsub("\n", "", flags, fixed = TRUE)
 
@@ -727,18 +755,38 @@ get_cmdstan_flags <- function(flag_name) {
   paste(flags, collapse = " ")
 }
 
+check_sundials_fpic <- function(verbose) {
+  if (!os_is_linux()){
+    return(invisible(NULL))
+  }
+  sundials_flags <- get_cmdstan_flags("CPPFLAGS_SUNDIALS")
+  local_flags <- cmdstan_make_local()
+  if (any(grepl("-fPIC", c(sundials_flags, local_flags), fixed = TRUE))) {
+    return(invisible(NULL))
+  }
+  if (interactive()) {
+    message("SUNDIALS needs to be compiled with -fPIC when exposing functions or ",
+            "model methods on Linux.\n",
+            "Updating your make/local file to include -fPIC and rebuilding CmdStan now...")
+  }
+  cmdstan_make_local(cpp_options = list("CPPFLAGS_SUNDIALS += -fPIC"), append = TRUE)
+  rebuild_cmdstan(quiet = !verbose)
+  if (interactive()) {
+    message("CmdStan has been rebuilt, continuing with model compilation...")
+  }
+}
+
 rcpp_source_stan <- function(code, env, verbose = FALSE, ...) {
+  check_sundials_fpic(verbose)
   cxxflags <- get_cmdstan_flags("CXXFLAGS")
   cmdstanr_includes <- system.file("include", package = "cmdstanr", mustWork = TRUE)
   cmdstanr_includes <- paste0(" -I\"", cmdstanr_includes,"\"")
-  libs <- c("LDLIBS", "LIBSUNDIALS", "TBB_TARGETS", "LDFLAGS_TBB")
+  libs <- c("LDLIBS", "LIBSUNDIALS", "TBB_TARGETS", "LDFLAGS_TBB", "SUNDIALS_TARGETS")
   libs <- paste(sapply(libs, get_cmdstan_flags), collapse = " ")
   if (.Platform$OS.type == "windows") {
     libs <- paste(libs, "-fopenmp")
   }
-  lib_paths <- c("/stan/lib/stan_math/lib/tbb/",
-                 "/stan/lib/stan_math/lib/sundials_6.1.1/lib/")
-  withr::with_path(paste0(cmdstan_path(), lib_paths),
+  withr::with_path(repair_path(file.path(cmdstan_path(),"stan/lib/stan_math/lib/tbb")),
     withr::with_makevars(
       c(
         USE_CXX14 = 1,
@@ -753,6 +801,9 @@ rcpp_source_stan <- function(code, env, verbose = FALSE, ...) {
 }
 
 expose_model_methods <- function(env, verbose = FALSE, hessian = FALSE) {
+  if (rlang::is_interactive()) {
+    message("Compiling additional model methods...")
+  }
   code <- c(env$hpp_code_,
             readLines(system.file("include", "model_methods.cpp",
                                   package = "cmdstanr", mustWork = TRUE)))
@@ -1001,7 +1052,9 @@ expose_stan_functions <- function(function_env, global = FALSE, verbose = FALSE)
       })
     }
   } else {
-    message("Compiling standalone functions...")
+    if (rlang::is_interactive()) {
+      message("Compiling standalone functions...")
+    }
     compile_functions(function_env, verbose, global)
   }
   invisible(NULL)
